function [x,A] = bdp_wr(x,N,lambda_1,lambda_2);
// bdp
// Backwards Dominating Process for Widom-Rowlinson
//   Input Variable
//     x         The starting configuration
//     N         The number of events to generate
//     lambda_1  The intensity of the process for Type I points
//     lambda_2  The intensity of the process for Type II points
//
//   Output Variable
//     A       The list of births and deaths (birth = 0, death = 1)

// Start at time 0 with no events
t = 0;
lambda = lambda_1 + lambda_2;   //  
A = [0 0 0 0 0];

// Use loop to run through the N events
for loop = 1:N
  t_d = grand(1,'exp',1/lambda)  // Time until next death event
  // find the number of points in the configuration
  s = size(x);
  s = s(1);
  if (s > 0)
    t_b = grand(1,'exp',1/s);
  else
    t_b = 2*t_d;
  end;
  m = grand(1,'unf',0.00000001,1)
  if t_d < t_b // then there is a death
    v = rand(1,2,'uniform');
    x = [x;v 1*(m < lambda_1 / (lambda_1 + lambda_2))];
    t = t - t_d;
    A = [A;t 1 v m];
  else
    w_index = grand(1,'uin',1,s);
    w = x(w_index,1:2);  // record the point to be removed
    x(w_index,:) = x(s,:);  // replace w_index with x(s)
    x = x(1:(s-1),:);  // remove point x(s)
    t = t - t_b;
    A = [A;t 0 w m];
  end
end;

// Remove first dummy row of A
s = size(A);
s = s(1);
A = A(2:s,:);

endfunction;
