function [f] = config_plot(x,r);
// config_plot
//   Plots a spatial configuration with circles around
//   the points of radius r
//
//   Input Variable
//     x      The configuration
//     r      The radius of interaction
//   Output Variable
//     f      Handle to the figure
//
//   Author:  Mark Huber
//   Begun:  Dec. 11, 2006
//   Last modified:  Dec. 11, 2006

// Create a new plot
f = scf();
set(f,"figure_size",[500 500]);
a = gca(f);
a.data_bounds = [0 0 1 1];
a.tight_limits = "on";

if ~(isempty(x))
  plot(x(:,1),x(:,2),'x');

  // Find number of points in x
  s = size(x);
  s = s(1);

  // Create a circle with twenty points in it around (0,0)
  ncp= 100; // ncp = *n*umber of *c*ircle *p*oints
  circle = zeros(ncp + 1,2);
  for i=1:ncp + 1;
    circle(i,:) = [cos(2*%pi*i/ncp),sin(2*%pi*i/ncp)]*r/2;
  end;

  // Create a circle around each point with twenty smaller points
  for loop1 = 1:s
    y = ones(ncp + 1,1)*x(loop1,:) + circle;
    plot(y(:,1),y(:,2));
  end;
end;

endfunction
