function [f] = config_plot_bounding_wr(x,r,b);
// config_plot
//   Plots a spatial configuration with circles around
//   the points of radius r
//
//   Input Variable
//     a        The number of points only in lower chain
//     b        The number of points in lower chain
//     x        The upper bound
//     r        The radius of interaction
//   Output Variable
//     f        Handle to the figure
//
//   Author:  Mark Huber
//   Begun:  Dec. 11, 2006
//   Last modified:  Dec. 12, 2006

// Create a new plot
f = scf();
set(f,"figure_size",[500 500]);
a = gca(f);
a.data_bounds = [0 0 1 1];
a.tight_limits = "on";

// Find number of points in upper chain
s = size(x);
s = s(1);

// Plot the points in lower and upper chain in green for type 1
if (b > 0)
  plot(x(1:b,1),x(1:b,2),'xg');
end;

// Plot the points in upper chain in red
if (b < s);
  plot(x(b+1:s,1),x(b+1:s,2),'xr');
end;

// Create a circle with twenty points in it around (0,0)
ncp= 100; // ncp = *n*umber of *c*ircle *p*oints
circle = zeros(ncp + 1,2);
for i=1:ncp + 1;
  circle(i,:) = [cos(2*%pi*i/ncp),sin(2*%pi*i/ncp)]*r/2;
end;

// Create a circle around each point with twenty smaller points
for loop1 = 1:s
  y = ones(ncp + 1,1)*x(loop1,1:2) + circle;
  if (loop1 <= b) & (x(loop1,3) == 0)
    plot(y(:,1),y(:,2),'-g');
  end;
  if (loop1 <= b) & (x(loop1,3) == 1)
    plot(y(:,1),y(:,2),'-b');
  end;
  if (loop1 > b) & (x(loop1,3) == 0)
    plot(y(:,1),y(:,2),'-r');
  end;  
  if (loop1 > b) & (x(loop1,3) == 1)
    plot(y(:,1),y(:,2),'-m');
  end;  
end;

endfunction
