function [y,n] = dcftp_hc(ninitial,lambda,min_distance,display,p_swap);
// dcftp_hc
//   Dominated coupling from the past for the hard core model
//
//   Input Variable
//     ninitial     The initial number of steps to take
//     lambda       The value of lambda
//     min_distance The closest distance two points can be to one another
//     display      =1 to give plot of result
//
//   Output Variable
//     x           The final configuration
//     n           The number of events generated


// Choose initial configuration
x = spp(lambda);
b = 0;   // No states are known in lower state at this point
s = size(x);
s = s(1);

// Set up the number of events to generate
oldn = 0;
n = ninitial;
A = [];

// Generate more and more events until get convergence
while (b < s)
  // Generate n-oldn events
  if (isempty(A))
    [x,A] = bdp(x,n - oldn,lambda);
  else
    [x,B] = bdp(x,n - oldn,lambda);
    A = [A;B];
  end;
  y = x;
  b = 0;
  // Generate forward to see if convergence occurs
  for loop1 = n:-1:1
    [b,y] = hcbpupdatepartialswap(A(loop1,1:4),A(loop1,5),b,y,min_distance,p_swap);
  end;
  // Recompute the size of the upper chain
  s = size(y);
  s = s(1);

  if (display == 1)
    f = config_plot_bounding(y,.05,b);
    s1 = string(n);
    s2 = "Number of events:  ";
    f.figure_name = strcat([s2,s1]);
  end;

  oldn = n;
  n = 2*n; 

end;

// After success, reset n variable
n = oldn;

endfunction;
