function [y,n] = dcftpswap_wr(ninitial,lambda_1,lambda_2,min_distance,display);
// dcftpswap_wr
//   Dominated coupling from the past for Widom-Rowlinson
//
//   Input Variable
//     ninitial     The initial number of steps to take
//     lambda_1     The value of lambda for Type I particles
//     lambda_2     The value of lambda for Type II particles
//     min_distance The minimum distance between events with different types
//
//   Output Variable
//     x           The final configuration
//     n           The number of events generated
//
//   Author:  Mark Huber
//   Last Update:  Feb 11, 2007

// Choose initial configuration
x = spp_wr(lambda_1,lambda_2);
s = size(x);
s = s(1);
b = 0;   // No states are known in lower state at this point

// Set up the number of events to generate
oldn = 0;
n = ninitial;
A = [];

// Generate more and more events until get convergence
while (b < s)
  // Generate n-oldn events
  if (isempty(A))
    [x,A] = bdp_wr(x,n - oldn,lambda_1 + lambda_2);
  else
    [x,B] = bdp_wr(x,n - oldn,lambda_1 + lambda_2);
    A = [A;B];
  end;
  y = x;
  b = 0;
  // Generate forward to see if convergence occurs
  for loop1 = n:-1:1
    [b,y] = wrbpupdateswap(A(loop1,:),A(loop1,5),b,y,min_distance,lambda_1,lambda_2);
  end;
  // Recompute the size of the upper chain
  s = size(y);
  s = s(1);
  oldn = n;
  n = 2*n; 

  if (display == 1)
    f = config_plot_bounding_wr(y,min_distance,b);
    s1 = string(n);
    s2 = "Number of events:  ";
    f.figure_name = strcat([s2,s1]);
  end;

end;

// After success, reset the n variable
n = oldn;

endfunction;
