function [V,A] = generate_lattice(k,properties)
// generate_lattace
//   Creates a lattice structure adjacency matrix

//   Input Variables
//     k              The number of nodes on a side
//     properties     The kind of lattice (1 = diagonals included)
//   Output Variables
//     V              the numbering of the nodes
//     A              a k^2 by 9matrix of adjacencies

// Initialize A and V
A = zeros(k^2,9);
V = zeros(k^2,2);

// Cycle through all x and y coordinates of lattice
for loop1 = 1:k
  for loop2 = 1:k
    node = (loop1 - 1)*k + loop2;   // The number of the node
    // Write down the node in the proper row
    V(node,1) = loop1;
    V(node,2) = loop2;
    neighbors = 0;  // Number of adjacent nodes the neighbor has
    // There are eight possible neighbors:  N, NE, E, SE, S, SW, W, NW
    //   N
    if (loop1 > 1)  // Then node above is a neighbor
      neighbors = neighbors + 1;
      A(node,neighbors + 1) = (loop1 - 2)*k + loop2;
    end;
    //   NE
    if (loop1 > 1) & (loop2 < k)  // Then node above is a neighbor
      neighbors = neighbors + 1;
      A(node,neighbors + 1) = (loop1 - 2)*k + loop2 + 1;
    end;
    //   E
    if (loop2 < k)  // Then node above is a neighbor
      neighbors = neighbors + 1;
      A(node,neighbors + 1) = (loop1 - 1)*k + loop2 + 1;
    end;
    //   SE
    if (loop2 < k) & (loop1 < k) // Then node above is a neighbor
      neighbors = neighbors + 1;
      A(node,neighbors + 1) = (loop1)*k + loop2 + 1;
    end;
    //   S
    if (loop1 < k)  // Then node above is a neighbor
      neighbors = neighbors + 1;
      A(node,neighbors + 1) = (loop1)*k + loop2;
    end;
    //   SW
    if (loop1 < k) & (loop2 > 1) // Then node above is a neighbor
      neighbors = neighbors + 1;
      A(node,neighbors + 1) = (loop1)*k + loop2 - 1;
    end;
    //   W
    if (loop2 > 1)  // Then node above is a neighbor
      neighbors = neighbors + 1;
      A(node,neighbors + 1) = (loop1 - 1)*k + loop2 - 1;
    end;
    //  NW
    if (loop2 > 1) & (loop1 > 1)  // Then node above is a neighbor
      neighbors = neighbors + 1;
      A(node,neighbors + 1) = (loop1 - 2)*k + loop2 - 1;
    end;
    A(node,1) = neighbors;
  end;
end;
    
 endfunction;
