function [b,x] = hcbpupdatenoswap(step,b,x,R)
// hcbpupdateno swap
//   Hard-core bounding process update takes one step in the Markov chain
//   with no swap move
//
//   Input Variables:
//     step      Encodes the step in the process
//     b         The number of point in the lower process
//     x         The set of points (first b of which are lower, rest upper)
//     R         The minimum distance between two points
//
// Author:  Mark L. Huber
// Last Update:  Jan 21, 2007

// Find out size of upper chain in x
s = size(x);
s = s(1);

if step(2) == 0  // Then there was a birth, check to see if point in range
  nl = 0;
  nu = 0;
  if (b > 0)
    for loop1 = 1:b
       if (sqrt(sum((step(3:4) - x(loop1,:)).^2)) < R)
         nu = nu + 1;
         nl = nl + 1;
       end;
     end;
  end;
  if (b < s)
    for loop1 = (b+1):s
      if (sqrt(sum((step(3:4) - x(loop1,:)).^2)) < R)
        nu = nu + 1;
      end;
    end;
  end;
   
   // If no neighbors in lower chain, add to upper chain
   if (nl == 0)
     if isempty(x);
       x = step(3:4);
     else
       x = [x;step(3:4)];
     end
   end;

   // If no neighbors in upper chain, add to lower chain as well
   if nu == 0
     b = b + 1;
     x(s+1,:) = x(b,:);
     x(b,:) = step(3:4);
   end

else  // The move is a death
  w = 0;
  // Find the point that died
  for loop1 = 1:s
    if sum(step(3:4) == x(loop1,:)) == 2 // then this is it
      w = loop1;
    end
  end
  // move point to end of configuration, and update a, b accordingly
  if (w > 0) // then found the point
    if (w <= b) // it should be removed from lower and upper chain
      x(w,:) = x(b,:);
      x(b,:) = x(s,:);
      b = b - 1;
    else
      x(w,:) = x(s,:);
    end;
    x = x(1:(s-1),:); // lop off last point in configuration
  end;
end;

endfunction;
