function [b,x] = hcbpupdateswap(step,b,x,R)
// hcbpupdateswap
//   Hard-core bounding process update takes one step in the Markov chain
//   with a swap move
//
//   Input Variables:
//     step      Encodes the step in the process
//     b         The number of point in the lower process
//     x         The set of points (first b of which are lower, rest upper)
//     R         The minimum distance between two points

// Find out size of upper chain in x
s = size(x);
s = s(1);

if step(2) == 0  // Then there was a birth, check to see if point in range
  nl = 0;
  nu = 0;
  if (b > 0)
    for loop1 = 1:b
       if (sqrt(sum((step(3:4) - x(loop1,:)).^2)) < R)
         nu = nu + 1;
         nl = nl + 1;
         lower_block = loop1;
         upper_block = loop1;
       end;
     end;
  end;
  if (b < s)
    for loop1 = (b+1):s
      if (sqrt(sum((step(3:4) - x(loop1,:)).^2)) < R)
        nu = nu + 1;
        upper_block = loop1
      end;
    end;
  end;
   
  if (nu == 0) // Case I: add point to lower and upper chain
    if isempty(x);
      x = step(3:4);
    else
      x = [x;step(3:4)];
    end
    b = b + 1;
    x(s+1,:) = x(b,:);
    x(b,:) = step(3:4);
  end;     

  if (nu == 1) // Case II: add point to lower and upper, remove block
    if (nl == 0);  // just replace upper chain block with new point
      b = b + 1;
      x(upper_block,:) = x(b,:);
      x(b,:) = step(3:4);
    else  // replace blocking point with new point
      x(lower_block,:) = step(3:4);
    end;
  end;     

  if (nu > 1) & (nl == 0) // Case III: add point to upper chain
    if isempty(x);
      x = step(3:4);
    else
      x = [x;step(3:4)];
    end
  end;
   
  // Case IV:  remove block from lower, and add new point to upper
  if (nu > 1) & (nl == 1)
    temp = x(lower_block,:);   // swap lower_block and b
    x(lower_block,:) = x(b,:)
    x(b,:) = temp;
    b = b - 1; // reduce number of lower chain points by 1;
    // add the new point to the upper chain
    if isempty(x);
      x = step(3:4);
    else
      x = [x;step(3:4)];
    end
  end
   
else  // The move is a death
  w = 0;
  // Find the point that died
  for loop1 = 1:s
    if sum(step(3:4) == x(loop1,:)) == 2 // then this is it
      w = loop1;
    end
  end
  // move point to end of configuration, and update a, b accordingly
  if (w > 0) // then found the point
    if (w <= b) // it should be removed from lower and upper chain
      x(w,:) = x(b,:);
      x(b,:) = x(s,:);
      b = b - 1;
    else
      x(w,:) = x(s,:);
    end;
    x = x(1:(s-1),:); // lop off last point in configuration
  end;
end;

endfunction;
